==> topia-persistence-2.3.4-test-sources.jar: org/nuiton/topiatest/Personne.java <==
package org.nuiton.topiatest;

import java.util.Collection;
import org.nuiton.topia.persistence.TopiaEntity;
import org.nuiton.topiatest.deletetest.Party2;


public interface Personne extends Party2 {     String NAME = "name";
     String OTHER_NAMES = "otherNames";
     String GENDER = "gender";
     String ADDRESS = "address";
    /**
     * setName :
     * @param name La valeur de l'attribut name à positionner.
     */

     void setName(String name);

    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * addOtherNames :
     * @param otherNames L'instance de otherNames à ajouter
     */

     void addOtherNames(String otherNames);

    /**
     * addAllOtherNames :
     * @param otherNames Les instances de otherNames à ajouter
     */

     void addAllOtherNames(Collection<String> otherNames);

    /**
     * setOtherNames :
     * @param otherNames La Collection de otherNames à ajouter
     */

     void setOtherNames(Collection<String> otherNames);

    /**
     * removeOtherNames :
     * @param otherNames Vide la Collection de otherNames
     */

     void removeOtherNames(String otherNames);

    /**
     * clearOtherNames :
     */

     void clearOtherNames();

    /**
     * getOtherNames :
     * @return Collection<String> 
     */

     Collection<String> getOtherNames();

    /**
     * sizeOtherNames :
     * Retourne le nombre d'éléments de la collection otherNames
     * @return int 
     */

     int sizeOtherNames();

    /**
     * isOtherNamesEmpty :
     * Retourne {@code true} si la collection otherNames est vide.
     * @return boolean 
     */

     boolean isOtherNamesEmpty();

    /**
     * setGender :
     * @param gender La valeur de l'attribut gender à positionner.
     */

     void setGender(boolean gender);

    /**
     * getGender :
     * @return boolean 
     */

     boolean getGender();

    /**
     * isGender :
     * @return boolean 
     */

     boolean isGender();

    /**
     * setAddress :
     * @param address La valeur de l'attribut address à positionner.
     */

     void setAddress(Address address);

    /**
     * getAddress :
     * @return Address 
     */

     Address getAddress();


} //Personne

==> topia-persistence-2.4.3-test-sources.jar: org/nuiton/topiatest/Personne.java <==
package org.nuiton.topiatest;

import java.util.Collection;
import org.nuiton.topiatest.deletetest.Party2;


public interface Personne extends Party2 {     String PROPERTY_NAME = "name";
     String PROPERTY_OTHER_NAMES = "otherNames";
     String PROPERTY_GENDER = "gender";
     String PROPERTY_ADDRESS = "address";
    /**
     * setName :
     * @param name La valeur de l'attribut à positionner.
     */

     void setName(String name);

    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * addOtherNames :
     * @param otherNames L'instance de java.lang.String à ajouter
     */

     void addOtherNames(String otherNames);

    /**
     * addAllOtherNames :
     * @param otherNames Les instances de java.lang.String à ajouter
     */

     void addAllOtherNames(Collection<String> otherNames);

    /**
     * setOtherNames :
     * @param otherNames La valeur de l'attribut à positionner.
     */

     void setOtherNames(Collection<String> otherNames);

    /**
     * removeOtherNames :
     * @param otherNames L'instance de java.lang.String à retirer
     */

     void removeOtherNames(String otherNames);

    /**
     * clearOtherNames :
     */

     void clearOtherNames();

    /**
     * getOtherNames :
     * Retourne la collection.
     * @return Collection<String> 
     */

     Collection<String> getOtherNames();

    /**
     * sizeOtherNames :
     * Retourne le nombre d'éléments de la collection otherNames
     * @return int 
     */

     int sizeOtherNames();

    /**
     * isOtherNamesEmpty :
     * Retourne {@code true} si la collection otherNames est vide.
     * @return boolean 
     */

     boolean isOtherNamesEmpty();

    /**
     * setGender :
     * @param gender La valeur de l'attribut à positionner.
     */

     void setGender(boolean gender);

    /**
     * getGender :
     * @return boolean 
     */

     boolean getGender();

    /**
     * isGender :
     * @return boolean 
     */

     boolean isGender();

    /**
     * setAddress :
     * @param address La valeur de l'attribut à positionner.
     */

     void setAddress(Address address);

    /**
     * getAddress :
     * @return Address 
     */

     Address getAddress();


} //Personne
